@@ -28,7 +28,9 @@ def log_test2():
 def log_test3():
     logger = logging.getLogger()
     logger.error('123')
+    import datetime
+    print(datetime.datetime.now())
 
 
 if __name__ == '__main__':
-    log_test()
+    log_test3()
